@@ -6,9 +6,10 @@ from datetime import datetime
 
 import click
 import redis
+import yaml
 from rich.console import Console
 
-from motion import clear_instance, inspect_state
+from motion import clear_instance, get_instances, inspect_state
 
 
 @click.group()
@@ -17,6 +18,36 @@ def motioncli() -> None:
     pass
 
 
+@motioncli.command("init", epilog="Example usage:\n motion init")
+def init() -> None:
+    """Initializes a motion project."""
+    # If .motionrc.yml already exists, do nothing
+    if os.path.exists(".motionrc.yml"):
+        click.echo("A .motionrc.yml file already exists in this directory.")
+        return
+
+    console = Console()
+    checkmark = "\u2705"
+
+    config = {
+        "MOTION_REDIS_HOST": os.getenv("MOTION_REDIS_HOST", "localhost"),
+        "MOTION_REDIS_PORT": int(os.getenv("MOTION_REDIS_PORT", "6379")),
+        "MOTION_REDIS_DB": int(os.getenv("MOTION_REDIS_DB", "0")),
+        "MOTION_REDIS_PASSWORD": os.getenv("MOTION_REDIS_PASSWORD"),
+        "MOTION_REDIS_SSL": os.getenv("MOTION_REDIS_SSL", False),
+        "MOTION_ENV": os.getenv("MOTION_ENV", "dev"),
+    }
+
+    # Creates an .motionrc.yml file
+    with console.status("Creating .motionrc.yml", spinner="dots"):
+        with open(".motionrc.yml", "w") as f:
+            # Write the following
+            yaml.dump(config, f)
+
+    # Done
+    click.echo(f"{checkmark} Created .motionrc.yml in current directory {os.getcwd()}.")
+
+
 @motioncli.command(
     "vis",
     epilog="Example usage:\n motion vis main.py:MyComponent",
@@ -115,13 +146,13 @@ def inspect(instance: str) -> None:
     any loadState() transformations.
 
     Args:
-        instance (str): Instance name of the component to clear.
+        instance (str): Instance name of the component to inspect.
             In the form `componentname__instancename`.
     """
     console = Console()
     red_x = "\u274C"
     checkmark = "\u2705"  # Unicode code point for checkmark emoji
-    with console.status("Clearing instance", spinner="dots"):
+    with console.status("Inspecting instance", spinner="dots"):
         try:
             state = inspect_state(instance)
         except ValueError as e:
@@ -135,5 +166,34 @@ def inspect(instance: str) -> None:
     click.echo(f"{checkmark} Printed state for instance {instance}.")
 
 
+@motioncli.command("list", epilog="Example usage:\n motion list MyComponent")
+@click.argument("component", type=str, required=True)
+def list(component: str) -> None:
+    """Lists all instances of a component.
+
+    Args:
+        component (str): Name of the component to list instances of.
+    """
+    console = Console()
+    red_x = "\u274C"
+    checkmark = "\u2705"  # Unicode code point for checkmark emoji
+    with console.status("Getting instances for component", spinner="dots"):
+        try:
+            instances = get_instances(component)
+        except ValueError as e:
+            click.echo(f"{red_x} {e}")
+            return
+        except redis.exceptions.ConnectionError as e:
+            click.echo(f"{red_x} {e}")
+            return
+
+    for instance_id in instances:
+        console.print(instance_id)
+
+    click.echo(
+        f"{checkmark} Listed all {len(instances)} instances for component {component}."
+    )
+
+
 if __name__ == "__main__":
     motioncli()
